pub enum ExecuteMsg {
Show 15 variants
Transfer {
recipient: String,
amount: Uint128,
},
TransferVesting {
recipient: String,
amount: Uint128,
schedule: Curve,
},
Burn {
amount: Uint128,
},
Send {
contract: String,
amount: Uint128,
msg: Binary,
},
IncreaseAllowance {
spender: String,
amount: Uint128,
expires: Option<Expiration>,
},
DecreaseAllowance {
spender: String,
amount: Uint128,
expires: Option<Expiration>,
},
TransferFrom {
owner: String,
recipient: String,
amount: Uint128,
},
SendFrom {
owner: String,
contract: String,
amount: Uint128,
msg: Binary,
},
BurnFrom {
owner: String,
amount: Uint128,
},
Mint {
recipient: String,
amount: Uint128,
},
UpdateMinter {
minter: String,
},
UpdateMarketing {
project: Option<String>,
description: Option<String>,
marketing: Option<String>,
},
UploadLogo(Logo),
AllowVester {
address: String,
},
DenyVester {
address: String,
},
}Variants
Transfer
Transfer is a base message to move tokens to another account without triggering actions
TransferVesting
TransferVesting is a base message to move tokens to another account without triggering actions. The sent tokens will be slowly released based on the attached schedule. If the recipient already has an existing vesting schedule, this will fail.
Fields
Burn
Burn is a base message to destroy tokens forever
Send
Send is a base message to transfer tokens to a contract and trigger an action on the receiving contract.
IncreaseAllowance
Only with “approval” extension. Allows spender to access an additional amount tokens from the owner’s (env.sender) account. If expires is Some(), overwrites current allowance expiration with this one.
DecreaseAllowance
Only with “approval” extension. Lowers the spender’s access of tokens from the owner’s (env.sender) account by amount. If expires is Some(), overwrites current allowance expiration with this one.
TransferFrom
Only with “approval” extension. Transfers amount tokens from owner -> recipient
if env.sender has sufficient pre-approval.
SendFrom
Only with “approval” extension. Sends amount tokens from owner -> contract
if env.sender has sufficient pre-approval.
BurnFrom
Only with “approval” extension. Destroys tokens forever
Mint
Only with the “mintable” extension. If authorized, creates amount new tokens and adds to the recipient balance.
UpdateMinter
Only with the “mintable” extension. If minter set and authorized by current minter, makes the new address the minter.
UpdateMarketing
Only with the “marketing” extension. If authorized, updates marketing metadata. Setting None/null for any of these will leave it unchanged. Setting Some(“”) will clear this field on the contract storage
Fields
UploadLogo(Logo)
If set as the “marketing” role on the contract, upload a new URL, SVG, or PNG for the token
AllowVester
If set, it will add an address to a permission list on TransferVesting
DenyVester
If set, it will remove an address to a permission list on TransferVesting