pub struct MinterInfo {
pub minter: String,
pub cap: Option<Curve>,
}Fields
minter: Stringcap: Option<Curve>cap is a hard cap on total supply that can be achieved by minting. This can be a monotonically increasing curve based on block time (constant value being a special case of this).
Note that cap refers to total_supply. If None, there is unlimited cap.