pub struct VestingAllowListResponse {
pub allow_list: Vec<String>,
}Fields
allow_list: Vec<String>Trait Implementations
Sourceimpl Clone for VestingAllowListResponse
impl Clone for VestingAllowListResponse
Sourcefn clone(&self) -> VestingAllowListResponse
fn clone(&self) -> VestingAllowListResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VestingAllowListResponse
impl Debug for VestingAllowListResponse
Sourceimpl<'de> Deserialize<'de> for VestingAllowListResponse
impl<'de> Deserialize<'de> for VestingAllowListResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VestingAllowListResponse
impl JsonSchema for VestingAllowListResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VestingAllowListResponse
impl PartialEq for VestingAllowListResponse
Sourceimpl Serialize for VestingAllowListResponse
impl Serialize for VestingAllowListResponse
impl StructuralPartialEq for VestingAllowListResponse